/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.bean;

/**
 * クライアント表示サイズの定数クラス<BR>
 * 
 * @version 5.0.0
 * @since 1.0.0
 */
public class SizeConstant {
	/** ボタン 高さ */
	public static final int SIZE_BUTTON_HEIGHT = 22;

	/** テキストボックス 高さ */
	public static final int SIZE_TEXT_HEIGHT = 15;

	/** コンボボックス 高さ */
	public static final int SIZE_COMBO_HEIGHT = 20;

	/** ラベル 高さ */
	public static final int SIZE_LABEL_HEIGHT = 15;

	/** URL入力 幅*/
	public static final int SIZE_TEXT_USERID_WIDTH = 100;

	/** URL入力 幅*/
	public static final int SIZE_TEXT_URL_WIDTH = 250;
}
